@@ -314,9 +314,9 @@ def test_translate_missing_input_files(tmpdir):
 @pytest.mark.parametrize(
     "content,num_nits",
     [
-        ({"ping": {"bugs": [12345]}}, 1),
-        ({"ping": {"bugs": [12345], "no_lint": ["BUG_NUMBER"]}}, 0),
-        ({"ping": {"bugs": [12345]}, "no_lint": ["BUG_NUMBER"]}, 0),
+        ({"search": {"bugs": [12345]}}, 1),
+        ({"search": {"bugs": [12345], "no_lint": ["BUG_NUMBER"]}}, 0),
+        ({"search": {"bugs": [12345]}, "no_lint": ["BUG_NUMBER"]}, 0),
     ],
 )
 def test_bug_number_pings(content, num_nits):
@@ -336,3 +336,19 @@ def test_bug_number_pings(content, num_nits):
     assert len(nits) == num_nits
     if num_nits > 0:
         assert set(["BUG_NUMBER"]) == set(v.check_name for v in nits)
+
+
+def test_redundant_pings():
+    """
+    Test that name contains '-ping' or 'ping-' or 'ping' or 'custom' yields lint errors.
+    """
+    content = {"ping": {}}
+
+    content = util.add_required_ping(content)
+    all_pings = parser.parse_objects([content])
+    errs = list(all_pings)
+    assert len(errs) == 0
+
+    nits = lint.lint_metrics(all_pings.value)
+    assert len(nits) == 1
+    assert set(["REDUNDANT_PING"]) == set(v.check_name for v in nits)
